//
//  TableListView.m
//  LDScrollView
//
//  Created by dzkj on 2021/8/24.
//

#import "TableListView.h"

#define CodeWidth 80
#define SCREEN_WIDTH [UIScreen mainScreen].bounds.size.width     //屏幕宽度
#define SCREEN_HEIGHT [UIScreen mainScreen].bounds.size.height    //屏幕高度

@interface TableListView()<UITableViewDelegate,UITableViewDataSource>

@property (nonatomic, strong) UIView *headerView;

@end

@implementation TableListView

-(instancetype)initWithFrame:(CGRect)frame WithTitleArr:(NSArray *)titleArr headArr:(NSArray *)headArr{
    if (self = [super initWithFrame:frame]) {
        self.titleArr = titleArr;
        self.headArr = headArr;
        [self loadLabel];
        [self loadTitleScrollView];
        [self addSubviews];
        [self loadScrollView];
        [self.tableView reloadData];
    }
    return self;
}

- (void)loadLabel{
    UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0, 46, 120, 20)];
    label.text = @"序";
    label.textColor = UIColor.blackColor;
    label.backgroundColor = UIColor.grayColor;
    label.font = [UIFont fontWithName:@"PingFangSC-Regular" size: 14];
    label.textAlignment = NSTextAlignmentCenter;
    [self addSubview:label];
}

- (void)loadTitleScrollView{
    UIScrollView *scrollview = [[UIScrollView alloc] initWithFrame:CGRectMake(120, 0, SCREEN_WIDTH-120, 80)];
    scrollview.bounces = false;
    scrollview.delegate = self;
    self.titleSC = scrollview;
    scrollview.delegate = self;
    scrollview.contentSize = CGSizeMake(CodeWidth*self.headArr.count, 0);
    scrollview.showsHorizontalScrollIndicator = false;
    for (NSInteger i=0; i<self.headArr.count; i++) {
        UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(i*CodeWidth, 46, CodeWidth, 20)];
        label.text = self.headArr[i];
        label.textColor = UIColor.blackColor;
        label.backgroundColor = UIColor.grayColor;
        label.font = [UIFont fontWithName:@"PingFangSC-Regular" size: 14];
        label.textAlignment = NSTextAlignmentCenter;
        [scrollview addSubview:label];
    }
    [self addSubview:scrollview];
}

-(void)addSubviews{
    [self addSubview:self.tableView];
}

-(UITableView *)tableView{
    if (nil == _tableView) {
        _tableView = [[UITableView alloc] initWithFrame:CGRectMake(0, 80, SCREEN_WIDTH, SCREEN_HEIGHT-80)];
        _tableView.delegate = self;
        _tableView.dataSource = self;
        _tableView.separatorStyle = UITableViewCellSeparatorStyleNone;
        [_tableView registerNib:[UINib nibWithNibName:@"DataSpeakStockListCell" bundle:nil] forCellReuseIdentifier:@"dataSpeakStockListCell"];
    }
    return _tableView;
}

- (void)loadScrollView{
    UIScrollView *scrollview = [[UIScrollView alloc] initWithFrame:CGRectMake(120, 0, SCREEN_WIDTH-120, self.titleArr.count*50)];
    scrollview.bounces = false;
    scrollview.delegate = self;
    self.centerSC = scrollview;
    scrollview.contentSize = CGSizeMake(CodeWidth*self.headArr.count, 0);
    scrollview.showsHorizontalScrollIndicator = false;
    for (NSInteger i=0; i<self.titleArr.count; i++) {
        for (NSInteger j=0; j<self.headArr.count; j++) {
            UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(j*CodeWidth, i*50, CodeWidth, 50)];
            label.text = [NSString stringWithFormat:@"%ld行%ld列",i+1,j+1];
            label.textColor = UIColor.blackColor;
            label.font = [UIFont fontWithName:@"PingFangSC-Regular" size: 14];
            label.textAlignment = NSTextAlignmentCenter;
            label.userInteractionEnabled = YES;
            UITapGestureRecognizer *tapGes = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(jumpToDetailVC:)];
            [label addGestureRecognizer:tapGes];
            [scrollview addSubview:label];
        }
    }
    [self.tableView addSubview:scrollview];
}

- (NSString *)transferStrToStr:(NSString *)str{
    CGFloat f = [str floatValue];
    return [NSString stringWithFormat:@"%.2f",f];
}

#define mark - UITableViewDelegate,UITableViewDataSource
-(NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    return self.titleArr.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    static NSString * cellIdentifier  = @"cell";
    UITableViewCell * cell = [tableView dequeueReusableCellWithIdentifier:cellIdentifier];
    if (!cell) {
        cell = [[UITableViewCell alloc] initWithStyle:(UITableViewCellStyleDefault) reuseIdentifier:cellIdentifier];
    }
    cell.selectionStyle = UITableViewCellSelectionStyleNone;
    cell.textLabel.text = [NSString stringWithFormat:@"%@",self.titleArr[indexPath.row]];
    
    return cell;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath{
    return 50;
}

-(CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section{
    return 80;
}

-(void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath{
    
}

-(void)scrollViewDidScroll:(UIScrollView *)scrollView{
    if (scrollView == self.titleSC) {
        self.centerSC.contentOffset = CGPointMake(self.titleSC.contentOffset.x, 0);
    }else if (scrollView == self.centerSC){
        self.titleSC.contentOffset = CGPointMake(self.centerSC.contentOffset.x, 0);
    }
}

- (void)jumpToDetailVC:(UITapGestureRecognizer*)tap{
    NSInteger index = tap.view.tag;
    
}

@end
